<h1>Department Search (Proxy)</h1>
<form method="get" action="department.json">
{% include 'proxy/sws/student/v5/includes/term.html' %}
{% include 'proxy/sws/student/v5/includes/college_abbreviation.html' %}
{% include 'proxy/sws/student/v5/includes/page_size.html' %}
<input value="Search" type="submit">
</form>
